#!/usr/bin/env bash
# ─< ANSI color codes >───────────────────────────────────────────────────────────────────
RED='\033[0;31m'
CYAN='\033[0;36m'
NC='\033[0m' # No Color

echo_error() {
  printf "${BOLD}${RED}ERROR: ${NC}${RED}%s${NC}\n" "$1" >&2
}

echo_info() {
  printf "${BOLD}${CYAN}INFO: ${NC}${CYAN}%s${NC}\n" "$1"
}

# ─< Check if the given command exists silently >─────────────────────────────────────────
command_exists() {
  command -v "$@" >/dev/null 2>&1
}

registry="git.k4li.de"
image="caddydb"
org="docker"
tag="latest"

container_="${registry}/${org}/${image}:${tag}"

D_push() {
  docker push "${container_}"
}

if command_exists docker; then
  if [ -e ./Dockerfile ]; then
    docker build -t "${container_}" .

    echo_info "Do you also want to push ${container_} ? (Y/n): "
    read -r askPush </dev/tty

    case "$askPush" in
    [Nn])
      return 0
      ;;
    *)
      D_push
      ;;
    esac

  else
    echo_error "There was no dockerfile present in this directory: $PWD"
  fi
else
  echo_error "Docker is not installed!"
fi
